@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-link-checker.cpp,v 1.7 2004/03/17 21:26:06 adamh Exp $
+ *  $Id: mozilla-link-checker.cpp,v 1.9 2004/04/19 04:00:43 adamh Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -33,20 +33,13 @@
 #include <nsIComponentManager.h>
 #include <nsIComponentRegistrar.h>
 #include <nsIDOMDocument.h>
-#include <nsIDOMHTMLAnchorElement.h>
 #include <nsIDOMHTMLCollection.h>
 #include <nsIDOMHTMLDocument.h>
 #include <nsIDOMNode.h>
 #include <nsIDOMWindow.h>
 #include <nsIGenericFactory.h>
-#include <nsIURI.h>
-#include <nsIURIChecker.h>
 #include <nsIWebBrowser.h>
 #include <nsNetCID.h>
-#include <nsNetUtil.h>
-#include <nsString.h>
-
-#include <glib/gi18n-lib.h>
 
 NS_GENERIC_FACTORY_CONSTRUCTOR(ErrorViewerURICheckerObserver)
 
@@ -115,11 +108,6 @@ mozilla_check_links (LinkChecker *checker,
 		     EphyEmbed *embed)
 {
 	nsresult rv;
-	
-	nsCOMPtr<ErrorViewerURICheckerObserver> observer = do_CreateInstance
-		(G_ERRORVIEWERURICHECKEROBSERVER_CONTRACTID);
-	observer->mChecker = G_OBJECT (checker);
-	observer->mFilename = ephy_embed_get_location (embed, FALSE);
 
 	nsCOMPtr<nsIWebBrowser> browser;
 	gtk_moz_embed_get_nsIWebBrowser (GTK_MOZ_EMBED (embed),
@@ -142,76 +130,22 @@ mozilla_check_links (LinkChecker *checker,
 	rv = html->GetLinks (getter_AddRefs (links));
 	g_return_if_fail (NS_SUCCEEDED (rv));
 
-	links->GetLength (&observer->mNumLinksTotal);
+	nsCOMPtr<ErrorViewerURICheckerObserver> observer = do_CreateInstance
+		(G_ERRORVIEWERURICHECKEROBSERVER_CONTRACTID);
+	observer->Init (checker, ephy_embed_get_location (embed, FALSE));
 
-	char *msg;
-	
-	if (observer->mNumLinksTotal > 0)
-	{
-		msg = g_strdup_printf
-			(ngettext("Checking %d Link on %s",
-				  "Checking %d Links on %s",
-				  observer->mNumLinksTotal),
-			 observer->mNumLinksTotal, observer->mFilename);
-	}
-	else
-	{
-		msg = g_strdup_printf ("No links to check on %s",
-				       observer->mFilename);
-	}
+	PRUint32 numLinks;
+	rv = links->GetLength (&numLinks);
+	g_return_if_fail (NS_SUCCEEDED (rv));
 
-	link_checker_append (checker, ERROR_VIEWER_INFO, msg);
-
-	g_free (msg);
-
-	link_checker_update_progress (checker, observer->mFilename,
-				      0, 0, observer->mNumLinksTotal);
-
-	if (observer->mNumLinksTotal == 0) return;
-
-	for (PRUint32 i = 0; i < observer->mNumLinksTotal; i++)
+	for (PRUint32 i = 0; i < numLinks; i++)
 	{
 		nsCOMPtr<nsIDOMNode> node;
 		rv = links->Item (i, getter_AddRefs (node));
 		g_return_if_fail (NS_SUCCEEDED (rv));
 
-		nsCOMPtr<nsIDOMHTMLAnchorElement> anchor;
-		anchor = do_QueryInterface (node, &rv);
-		if (NS_FAILED (rv))
-		{
-			observer->mNumLinksChecked++;
-			continue;
-		}
-
-		nsAutoString href;
-		rv = anchor->GetHref (href);
-		if (NS_FAILED (rv))
-		{
-			observer->mNumLinksChecked++;
-			continue;
-		}
-
-		nsCOMPtr<nsIURI> uri;
-		rv = NS_NewURI (getter_AddRefs (uri),
-				NS_ConvertUCS2toUTF8 (href));
-		if (NS_FAILED (rv))
-		{
-			observer->mNumLinksChecked++;
-			continue;
-		}
-
-		nsCOMPtr<nsIURIChecker> uri_checker = do_CreateInstance
-			(NS_URICHECKER_CONTRACT_ID);
-
-		rv = uri_checker->Init (uri);
-		if (NS_FAILED (rv))
-		{
-			g_warning ("Couldn't init with URI pointed to %s",
-				   NS_ConvertUCS2toUTF8 (href).get ());
-			observer->mNumLinksChecked++;
-			continue;
-		}
-
-		uri_checker->AsyncCheck (observer, NULL);
+		observer->AddNode (node);
 	}
+
+	observer->DoneAdding ();
 }
